diff msite.inc.php @ 528:dd5c5577c495

Add preview file and file type fields for entry, for screenshots etc.
author Matti Hamalainen <ccr@tnsp.org>
date Tue, 10 Dec 2013 17:50:22 +0200
parents d6726a4883a6
children ec30ad303bd1
line wrap: on
line diff
--- a/msite.inc.php	Tue Dec 10 17:49:57 2013 +0200
+++ b/msite.inc.php	Tue Dec 10 17:50:22 2013 +0200
@@ -31,6 +31,7 @@
 define("SET_LEN_ENTRY_FILENAME", 128);
 define("SET_LEN_ENTRY_INFO", 1024);
 define("SET_LEN_ENTRY_NOTES", 1024);
+define("SET_LEN_ENTRY_PREVIEW_FILE", 128);
 
 define("SET_LEN_DISP_SLIDE_TITLE", 64);
 define("SET_LEN_DISP_SLIDE_TEXT", 4096);
@@ -40,8 +41,11 @@
 
 
 //
 // Entry flags, a bitfield
 //
+define("EPREV_IMAGE", 1);           // Preview is image (PNG, JPEG)
+define("EPREV_AUDIO", 2);           // Preview is audio (MP3)
+
 define("EFLAG_DISQUALIFIED", 1);    // Entry is disqualified
 define("EFLAG_PROBLEMS", 2);        // Has some problems
@@ -40,8 +41,11 @@
 
 //
-// Entry flags, a bitfield
+// Entry preview type (value) and flags (bitfield)
 //